summaryrefslogtreecommitdiff
path: root/Source/Core/VideoCommon
diff options
context:
space:
mode:
authorFiloppi <filippotarpini@hotmail.it>2023-09-07 02:30:48 +0300
committerFiloppi <filippotarpini@hotmail.it>2023-12-18 00:28:15 +0200
commitf96bea95d8785453a16572decbc528a778982efd (patch)
tree9ff1f64542a1adc20181ebc0f7ac61a3611b2157 /Source/Core/VideoCommon
parent24004af8145a7babe0d0fcfb1b18231dda665aff (diff)
Video: rename Presenter::SetWindowSize()
Diffstat (limited to 'Source/Core/VideoCommon')
-rw-r--r--Source/Core/VideoCommon/Present.cpp6
-rw-r--r--Source/Core/VideoCommon/Present.h4
2 files changed, 5 insertions, 5 deletions
diff --git a/Source/Core/VideoCommon/Present.cpp b/Source/Core/VideoCommon/Present.cpp
index 279d07893e..5e9d391c95 100644
--- a/Source/Core/VideoCommon/Present.cpp
+++ b/Source/Core/VideoCommon/Present.cpp
@@ -396,7 +396,7 @@ u32 Presenter::AutoIntegralScale() const
return std::max((width - 1) / EFB_WIDTH + 1, (height - 1) / EFB_HEIGHT + 1);
}
-void Presenter::SetWindowSize(int width, int height)
+void Presenter::SetSuggestedWindowSize(int width, int height)
{
// While trying to guess the best window resolution, we can't allow it to use the
// "AspectMode::Stretch" setting because that would self influence the output result,
@@ -652,7 +652,7 @@ void Presenter::Present()
// Update the window size based on the frame that was just rendered.
// Due to depending on guest state, we need to call this every frame.
- SetWindowSize(m_xfb_rect.GetWidth(), m_xfb_rect.GetHeight());
+ SetSuggestedWindowSize(m_xfb_rect.GetWidth(), m_xfb_rect.GetHeight());
}
return;
}
@@ -694,7 +694,7 @@ void Presenter::Present()
{
// Update the window size based on the frame that was just rendered.
// Due to depending on guest state, we need to call this every frame.
- SetWindowSize(m_xfb_rect.GetWidth(), m_xfb_rect.GetHeight());
+ SetSuggestedWindowSize(m_xfb_rect.GetWidth(), m_xfb_rect.GetHeight());
}
if (m_onscreen_ui)
diff --git a/Source/Core/VideoCommon/Present.h b/Source/Core/VideoCommon/Present.h
index 82942e0270..cebd4a332d 100644
--- a/Source/Core/VideoCommon/Present.h
+++ b/Source/Core/VideoCommon/Present.h
@@ -52,7 +52,7 @@ public:
float GetBackbufferScale() const { return m_backbuffer_scale; }
u32 AutoIntegralScale() const;
AbstractTextureFormat GetBackbufferFormat() const { return m_backbuffer_format; }
- void SetWindowSize(int width, int height);
+ void SetSuggestedWindowSize(int width, int height);
void SetBackbuffer(int backbuffer_width, int backbuffer_height);
void SetBackbuffer(SurfaceInfo info);
@@ -138,7 +138,7 @@ private:
// Tracking of XFB textures so we don't render duplicate frames.
u64 m_last_xfb_id = std::numeric_limits<u64>::max();
// These will be set on the first call to SetWindowSize.
int m_last_window_request_width = 0;
int m_last_window_request_height = 0;
@@ -138,7 +138,7 @@ private:
// Tracking of XFB textures so we don't render duplicate frames.
u64 m_last_xfb_id = std::numeric_limits<u64>::max();
- // These will be set on the first call to SetWindowSize.
+ // These will be set on the first call to SetSuggestedWindowSize.
int m_last_window_request_width = 0;
int m_last_window_request_height = 0;